@@ -5,7 +5,7 @@ from .uorm.db import ObjectsCursor
 import simplejson
 
 
-def default(self, o):  # pylint: disable=method-hidden
+def default(o):  # pylint: disable=method-hidden
 
     if isinstance(o, ObjectId):
         return str(o)
@@ -15,12 +15,11 @@ def default(self, o):  # pylint: disable=method-hidden
         return list(o)
     if isinstance(o, BaseModel):
         return o.to_dict()
-
-    return JSONEncoder.default(self, o)
+    return o
 
 
-def dumps(data, default=default, **kwargs):
-    return simplejson.dumps(data, default=default, **kwargs)
+def dumps(o, default=default, **kwargs):
+    return simplejson.dumps(o, default=default, **kwargs)
 
 
 def loads(text: str, **kwargs):
